
var maxLocations = tweetMapAttributes['max'];

var gLatitudeHistoryOptions = {
	zoom: 10,
	center: new google.maps.LatLng(0,0),
	mapTypeId: google.maps.MapTypeId[tweetMapAttributes['maptype']],
	mapTypeControl: tweetMapAttributes['mapcontrol'],
	mapTypeControlOptions: {
	    style: google.maps.MapTypeControlStyle[tweetMapAttributes['controlstyle']]
	},	
	zoomControl: tweetMapAttributes['zoomcontrol'],
	zoomControlOptions: {
		style: google.maps.ZoomControlStyle[tweetMapAttributes['zoomstyle']]
	},
	panControl: tweetMapAttributes['pancontrol'],
	streetViewControl: false,
	overviewMapControl : tweetMapAttributes['haveoverview'],
	overviewMapControlOptions: {
		opened : tweetMapAttributes['openoverview']
	},
	disableDefaultUI: tweetMapAttributes['disabledefaultui']
};

var tweetMap = new google.maps.Map(document.getElementById("tweetmap_map"), gLatitudeHistoryOptions);

var tweetMapMarkers = new Array();
var bounds = new google.maps.LatLngBounds();
var infowindow = new google.maps.InfoWindow({
	content: "holding...",
	maxWidth: 500
});
var pathCoordinates = new Array();

for(var i=0; i < tweets.length; i++) {
	var color = tweetMapAttributes['pastcolor'];
	var last = false;
	if(i == 0) {
		color = tweetMapAttributes['currentcolor'];
	}
	var zIndex = tweets.length - i;
	createMarker(tweets[i]['tweet_id'], tweets[i]['latitude'], tweets[i]['longitude'], tweets[i]['text'], tweets[i]['html_text'], tweets[i]['created_at'], zIndex, color);
	if(i == maxLocations-1) {
		break;
	}
}

if(tweetMapAttributes['showpath'] == true) {
	var path = new google.maps.Polyline({
	      path: pathCoordinates,
	      strokeColor: tweetMapAttributes['pathcolor'],
	      strokeOpacity: 1.0,
	      strokeWeight: tweetMapAttributes['pathweight']
	});
	path.setMap(tweetMap);
}

tweetMap.fitBounds(bounds);
tweetMap.setCenter(bounds.getCenter());

function createMarker(tweetId, lat, lng, title, textHtml, dateString, zIndex, color) {
	var latlng = new google.maps.LatLng(lat,lng);
	pathCoordinates.push(latlng);

	var marker = new StyledMarker({
		styleIcon: new StyledIcon(
			StyledIconTypes.MARKER, { color: color }
		),
		position: latlng,
		title:title,
		flat: true,
		zIndex: zIndex, 
		map: tweetMap
	});		
		
	google.maps.event.addListener(marker, 'click', function() {
		infowindow.setContent( '<div style="line-height:2em;padding-top:5px;text-align:left;">' + textHtml + '<a href="http://twitter.com/#!/' + twitterUser + '/status/' + tweetId + '" target="_blank">' + timeAgo(dateString) + '</a></div>' );
		infowindow.open(tweetMap, this);
	});
		
	tweetMapMarkers.push(marker);
	bounds.extend(latlng);
}

var browser = function() {
    var ua = navigator.userAgent;
    return { ie: ua.match(/MSIE\s([^;]*)/) };
}();

/**
 * relative time calculator
 * @param {string} twitter date string returned from Twitter API
 * @return {string} relative time like "2 minutes ago"
 */
var timeAgo = function(dateString) {
	var rightNow = new Date();
	var then = new Date(dateString);

	if (browser.ie) {
		// IE can't parse these crazy Ruby dates
		then = Date.parse(dateString.replace(/( \+)/, ' UTC$1'));
	}

	var diff = rightNow - then;

	var second = 1000,
    	minute = second * 60,
    	hour = minute * 60,
    	day = hour * 24,
    	week = day * 7;

	if (isNaN(diff) || diff < 0) { return ""; }
	if (diff < second * 2) { return "right now"; }
	if (diff < minute) { return Math.floor(diff / second) + " seconds ago"; }
	if (diff < minute * 2) { return "about 1 minute ago"; }
	if (diff < hour) { return Math.floor(diff / minute) + " minutes ago"; }
	if (diff < hour * 2) { return "about 1 hour ago"; }
	if (diff < day) { return  Math.floor(diff / hour) + " hours ago"; }
	if (diff > day && diff < day * 2) { return "yesterday"; }
	if (diff < day * 365) { return Math.floor(diff / day) + " days ago";
	} else { return "over a year ago"; }
};